@@ -1,8 +1,8 @@
 """Decorators and wrappers to redirect streams for processes"""
+from __future__ import print_function
+from __future__ import unicode_literals
 # Standard library imports
-import os
 import sys
-import logging
 import atexit
 # from contextlib import redirect_stdout, redirect_stderr
 
@@ -14,10 +14,11 @@ from char import char
 DICT_STREAMS_STATE = {}
 
 def return_stdout_stderr_to_usual_state():
-    if (sys.stdout != DICT_STREAMS_STATE["stdout"]):
+    """Return stdout and stderr back to the previous state"""
+    if sys.stdout != DICT_STREAMS_STATE["stdout"]:
         sys.stdout.close()
         sys.stdout = DICT_STREAMS_STATE["stdout"]
-    if (sys.stderr != DICT_STREAMS_STATE["stderr"]):
+    if sys.stderr != DICT_STREAMS_STATE["stderr"]:
         sys.stderr.close()
         sys.stderr = DICT_STREAMS_STATE["stderr"]
 
@@ -27,7 +28,7 @@ def redirect_stdout_stderr_to_files(
         str_stdout_file,
         str_stderr_file,
 ):
-    """"""
+    """Return stdout and stderr to the files"""
     DICT_STREAMS_STATE["stdout"] = sys.stdout
     sys.stdout = open(str_stdout_file, "w", buffering=1)
     DICT_STREAMS_STATE["stderr"] = sys.stderr
@@ -43,7 +44,7 @@ def wrapped_func(
         *args,
         **kwargs
 ):
-    """"""
+    """Wrapper to run function with outputs redirected to files"""
     redirect_stdout_stderr_to_files(
         str_stdout_file,
         str_stderr_file,
